/*
*    Copyright (c) 2014 eryar All Rights Reserved.
*
*        File    : Main.cpp
*        Author  : eryar@163.com
*        Date    : 2014-10-02 20:46
*        Version : 1.0v
*
*    Description : OpenCASCADE conic to BSpline curve-Parabola.
*
*      Key words : OpenCascade, Parabola, BSpline Curve, Convert
*/

#define HAVE_CONFIG_H

#include <gp_Parab2d.hxx>

#include <Convert_ParabolaToBSplineCurve.hxx>


void DumpConvertorInfo(const Convert_ConicToBSplineCurve &theConvertor)
{
	Standard_Integer aCounter = 0;
	
	std::cout << "Convert Result" << std::endl;
	std::cout << "Degree: " << theConvertor.Degree() << std::endl;
	std::cout << "Periodic: " << (theConvertor.IsPeriodic() ? "yes" : "no") << std::endl;
	
	std::cout << "Knots: " << std::endl;
	for (Standard_Integer i = 1;i <= theConvertor.NbKnots(); ++i)
	{
		for (Standard_Integer j = 1; j <= theConvertor.Multiplicity(i); ++j)
		{
			std::cout << ++aCounter << ": " << theConvertor.Knot(i) << std::endl;
		}
	}
	
	std::cout << "Poles(Weight): " << std::endl;
	for (Standard_Integer i = 1; i <= theConvertor.NbPoles(); ++i)
	{
		gp_Pnt2d aPole = theConvertor.Pole(i);
		
		std::cout << i << ": " << aPole.X() << ", " << aPole.Y() 
		<< " W(" << theConvertor.Weight(i) << ")" << std::endl;
	}
}

void TestParabolaConversion(void)
{
	gp_Parab2d aParabola(gp::OX2d(), 1.0);
	
	Convert_ParabolaToBSplineCurve aConvertor(aParabola, 1.0, M_PI);
	
	DumpConvertorInfo(aConvertor);
}

int main(int argc, char **argv)
{
	TestParabolaConversion();
	
	return 0;
}
